PaymentBrands class

This class contains constants representing various payment brands, such as mada, applePay, googlePay, samsungPay, credit, stcPay, masterCard, and visa.

Constructors

PaymentBrands()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

applePay → const String
credit → const String
googlePay → const String
mada → const String
masterCard → const String
samsungPay → const String
stcPay → const String
visa → const String