CustomUISTC class

Class CustomUISTC is used to store the payment type, checkout ID, and phone number for custom UI payment.

Constructors

CustomUISTC({required String checkoutId, required String phoneNumber})

Properties

checkoutId ↔ String
declares a string variable named checkoutId without assigning it an initial value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
paymentType ↔ String
initializes a variable named paymentType with the value PaymentConst.customUi.
getter/setter pair
phoneNumber ↔ String
The phone number for STC (Saudi Telecom Company) can vary depending on the specific region or service you are looking for
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited