model/google_pay_ui library

Classes

GooglePayUI
GooglePayUI class holds all the necessary data related to the Google Pay payment method. It is required to provide checkoutId and googlePayMerchantId when initializing the class. This is Android-only as Google Pay is not available on iOS.