GooglePayUI class

GooglePayUI class holds all the necessary data related to the Google Pay payment method. It is required to provide checkoutId and googlePayMerchantId when initializing the class. This is Android-only as Google Pay is not available on iOS.

Constructors

GooglePayUI({required String checkoutId, required String googlePayMerchantId, required String gatewayMerchantId, required String countryCode, required String currencyCode, required String amount, List<String> allowedCardNetworks = const ["VISA", "MASTERCARD", "MADA"], List<String> allowedCardAuthMethods = const ["PAN_ONLY", "CRYPTOGRAM_3DS"]})

Properties

allowedCardAuthMethods List<String>
Allowed card auth methods (e.g., "PAN_ONLY", "CRYPTOGRAM_3DS")
getter/setter pair
allowedCardNetworks List<String>
Allowed card networks (e.g., "VISA", "MASTERCARD")
getter/setter pair
amount String
Total amount for the transaction
getter/setter pair
checkoutId String
Checkout ID from HyperPay backend
getter/setter pair
countryCode String
Country code (e.g., "SA" for Saudi Arabia)
getter/setter pair
currencyCode String
Currency code (e.g., "SAR")
getter/setter pair
gatewayMerchantId String
Gateway merchant ID (HyperPay Entity ID)
getter/setter pair
googlePayMerchantId String
Google Pay Merchant ID from Google Pay Business Console
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
paymentType String
Payment type identifier
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited